#[repr(i32)]pub enum ContentFormat {
Natural = 0,
Compact = 1,
Ellipsized = 2,
}Variants
Natural = 0
The content should appear at its natural size.
Compact = 1
The content should appear in a smaller format without interactions, if possible.
This has no effect on text replies.
The related events of replies are not displayed.
Ellipsized = 2
Like Compact, but the content should be ellipsized if possible to show
only a single line.
Implementations
Sourceimpl ContentFormat
impl ContentFormat
Sourcefn register_enum() -> Type
fn register_enum() -> Type
Registers the enum only once.